@@ -3,10 +3,8 @@ from typing import Any, Callable, List, Optional, Dict, Union, Type
 
 import numpy as np
 import numpy.typing as npt
-import tensorflow as tf  # type: ignore
 
-from code_loader.contract.enums import DataStateType, DatasetMetadataType, \
-    DataStateEnum, LeapDataType, ConfusionMatrixValue
+from code_loader.contract.enums import DataStateType, DataStateEnum, LeapDataType, ConfusionMatrixValue
 from code_loader.contract.visualizer_classes import LeapImage, LeapText, LeapGraph, LeapHorizontalBar, \
     LeapTextMask, LeapImageMask, LeapImageWithBBox
 
@@ -21,9 +19,13 @@ SectionCallableInterface = Callable[[int, PreprocessResponse], npt.NDArray[np.fl
 
 MetadataSectionCallableInterface = Union[
     Callable[[int, PreprocessResponse], int],
+    Callable[[int, PreprocessResponse], Dict[str, int]],
     Callable[[int, PreprocessResponse], str],
+    Callable[[int, PreprocessResponse], Dict[str, str]],
     Callable[[int, PreprocessResponse], bool],
-    Callable[[int, PreprocessResponse], float]
+    Callable[[int, PreprocessResponse], Dict[str, bool]],
+    Callable[[int, PreprocessResponse], float],
+    Callable[[int, PreprocessResponse], Dict[str, float]]
 ]
 
 
@@ -52,7 +54,7 @@ VisualizerCallableInterface = Union[
 VisualizerCallableReturnType = Union[LeapImage, LeapText, LeapGraph, LeapHorizontalBar,
                                      LeapImageMask, LeapTextMask, LeapImageWithBBox]
 
-CustomCallableInterface = Callable[..., tf.Tensor]
+CustomCallableInterface = Callable[..., Any]
 
 
 @dataclass
@@ -63,11 +65,12 @@ class ConfusionMatrixElement:
     id: str = ''
 
 
-ConfusionMatrixCallableInterface = Callable[[tf.Tensor, tf.Tensor], List[List[ConfusionMatrixElement]]]
+ConfusionMatrixCallableInterface = Callable[[Any, Any], List[List[ConfusionMatrixElement]]]
 
-CustomCallableInterfaceMultiArgs = Callable[..., tf.Tensor]
+CustomCallableInterfaceMultiArgs = Callable[..., Any]
+CustomMultipleReturnCallableInterfaceMultiArgs = Callable[..., Dict[str, Any]]
 ConfusionMatrixCallableInterfaceMultiArgs = Callable[..., List[List[ConfusionMatrixElement]]]
-MetricCallableReturnType = Union[tf.Tensor, List[List[ConfusionMatrixElement]]]
+MetricCallableReturnType = Union[Any, List[List[ConfusionMatrixElement]]]
 
 
 @dataclass
@@ -113,7 +116,6 @@ class GroundTruthHandler(DatasetBaseHandler):
 class MetadataHandler:
     name: str
     function: MetadataSectionCallableInterface
-    type: DatasetMetadataType
 
 
 @dataclass
@@ -125,7 +127,7 @@ class PredictionTypeHandler:
 @dataclass
 class CustomLayerHandler:
     name: str
-    layer: Type[tf.keras.layers.Layer]
+    layer: Type[Any]
     init_arg_names: List[str]
     call_arg_names: List[str]
 
